@@ -330,6 +330,10 @@ panel_device_status_to_localized_string (NMDevice *nm_device,
                         /* TRANSLATORS: device status */
                         state_str = _("Cable unplugged");
                 }
+        } else if (state == NM_DEVICE_STATE_DISCONNECTED &&
+                   NM_IS_DEVICE_ETHERNET (nm_device)) {
+                /* TRANSLATORS: device status */
+                state_str = _("Disabled");
         }
         if (!state_str)
                 state_str = device_state_to_localized_string (state);
@@ -428,3 +432,22 @@ net_device_get_valid_connections (NMClient *client, NMDevice *device)
 
         return g_slist_reverse (valid);
 }
+
+gchar *
+net_device_get_ip6_addresses (NMIPConfig *ipv6_config)
+{
+        g_autoptr(GPtrArray) ipv6 = NULL;
+        GPtrArray *addresses;
+
+        addresses = nm_ip_config_get_addresses (ipv6_config);
+        if (addresses->len == 0) {
+                return NULL;
+        }
+        ipv6 = g_ptr_array_sized_new (addresses->len + 1);
+
+        for (int i = 0; i < addresses->len; i++) {
+                g_ptr_array_add (ipv6, (char *) nm_ip_address_get_address (g_ptr_array_index (addresses, i)));
+        }
+        g_ptr_array_add (ipv6, NULL);
+        return g_strjoinv ("\n", (char **) ipv6->pdata);
+}
