@@ -46,7 +46,6 @@ struct _CcUaPanel
 {
   CcPanel    parent_instance;
 
-  AdwNavigationView  *main_nav_view;
   AdwSwitchRow       *show_ua_menu_row;
   CcListRow          *seeing_row;
   CcListRow          *hearing_row;
@@ -90,7 +89,6 @@ cc_ua_panel_class_init (CcUaPanelClass *klass)
 
   gtk_widget_class_set_template_from_resource (widget_class, "/org/gnome/control-center/universal-access/cc-ua-panel.ui");
 
-  gtk_widget_class_bind_template_child (widget_class, CcUaPanel, main_nav_view);
   gtk_widget_class_bind_template_child (widget_class, CcUaPanel, show_ua_menu_row);
   gtk_widget_class_bind_template_child (widget_class, CcUaPanel, seeing_row);
   gtk_widget_class_bind_template_child (widget_class, CcUaPanel, hearing_row);
@@ -105,21 +103,6 @@ cc_ua_panel_class_init (CcUaPanelClass *klass)
   g_type_ensure (CC_TYPE_UA_ZOOM_PAGE);
 }
 
-static void
-on_subpage_set (CcUaPanel *self)
-{
-  AdwNavigationPage *subpage;
-  g_autofree gchar *tag = NULL;
-
-  g_object_get (self, "subpage", &tag, NULL);
-  if (!tag)
-    return;
-
-  subpage = adw_navigation_view_find_page (self->main_nav_view, tag);
-  if (subpage)
-    adw_navigation_view_push (self->main_nav_view, subpage);
-}
-
 static void
 cc_ua_panel_init (CcUaPanel *self)
 {
@@ -133,6 +116,4 @@ cc_ua_panel_init (CcUaPanel *self)
   g_settings_bind (self->a11y_settings, KEY_ALWAYS_SHOW_STATUS,
                    self->show_ua_menu_row, "active",
                    G_SETTINGS_BIND_DEFAULT);
-
-  g_signal_connect_object (self, "notify::subpage", G_CALLBACK (on_subpage_set), self, G_CONNECT_SWAPPED);
 }
